import { AxiosError } from "axios";
import { apiInstance } from "@/shared/config/apiConfig";
import { getServerSession } from "next-auth";
import { authConfig } from "@/shared/config/authConfig";
import { Container, Title } from "@/shared/ui";
import ProfileNav from "@/widgets/ProfileNav/ProfileNav";

const Profile = async ({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) => {
  const session = await getServerSession(authConfig);

  const getProfile = async () => {
    const Authorization = `Bearer ${session?.access_token}`;
    const config = {
      headers: {
        Authorization,
      },
    };
    try {
      const response = await apiInstance.get<{
        report_count: number;
      }>("/users/profile/", config);

      return response.data;
    } catch (error: unknown) {
      if (error instanceof AxiosError) console.log(error.message);
    }
  };

  const data = await getProfile();

  return (
    <div className="bg-[#FAFCFF] py-10">
      <Container className="flex flex-col">
        <ProfileNav report_count={data?.report_count as number} />
        {children}
      </Container>
    </div>
  );
};

export default Profile;
