import { Link } from "@/shared/config/navigation";
import { Title } from "@/shared/ui";
import React from "react";
import mapPin from "./icons/map-pin.png";
import Image from "next/image";

interface Props {
  id: number;
  id_of_card: string;
  data_rk: string;
  name_of_organization: string;
  type_of_buy: string;
  name_of_buy: string;
  date_of_publication_datetime: string;
  date_of_offer_datetime: string;
  current_timestamp: string;
  plan_summ_decimal: string;
  address_of_organization: string;
}
const TenderCard: React.FC<Props> = ({
  id,
  id_of_card,
  data_rk,
  name_of_organization,
  type_of_buy,
  name_of_buy,
  date_of_publication_datetime,
  date_of_offer_datetime,
  current_timestamp,
  plan_summ_decimal,
  address_of_organization,
}: Props) => {
  function formatNumber(value: string) {
    return new Intl.NumberFormat("ru-RU", {
      style: "decimal",
      useGrouping: true,
    }).format(parseInt(value));
  }
  return (
    <div className="w-full min-h-[213px] bg-white shadow-sm rounded-sm flex gap-[82px] items-center p-6">
      <div className="w-[830px] flex flex-col">
        <Title
          text={`№ ${id_of_card}`}
          className="font-bold text-[24px] mb-[48px]"
        />
        <Link
          href={{ pathname: `/tenders/${id}`, query: { тендер: name_of_buy } }}
        >
          <h2 className="mb-6 text-[18px] font-semibold leading-6 text-blue">
            {name_of_buy}
          </h2>
        </Link>
        <h2 className="text-[18px] leading-6 font-normal ">
          {name_of_organization}
        </h2>
      </div>
      <div className="w-[290px]">
        <p className="text-[14px] leading-6 mb-[6px]">Планируемая сумма</p>
        <Title
          text={formatNumber(plan_summ_decimal)}
          className="font-extrabold text-[24px] leading-[38px] mb-4"
        />

        <p className="text-[14px] leading-6 mb-4">
          Окончание приема заявок: {date_of_offer_datetime.slice(0, 10)}
        </p>
        <div className="text-[14px] leading-6 flex gap-2 items-baseline">
          <Image
            src={mapPin}
            alt="map"
            width={20}
            height={20}
            className="object-cover"
          />
          <p>{address_of_organization}</p>
        </div>
      </div>
    </div>
  );
};

export default TenderCard;
