import { AuthOptions } from "next-auth";
import { JWT } from "next-auth/jwt";
import CredentialsProvider from "next-auth/providers/credentials";
import { apiInstance } from "./apiConfig";
import { IRefresh, ITokens } from "../types/token-type";

const refreshToken = async (token: JWT): Promise<JWT> => {
  const UTC = new Date();

  const data = {
    refresh: token.refresh_token,
  };

  const response = await apiInstance.post<IRefresh>(
    "/auth/token/refresh/",
    data
  );

  const expirationTime = new Date(UTC.getTime() + 14 * 60000);
  expirationTime.setTime(
    expirationTime.getTime() +
      expirationTime.getTimezoneOffset() * 60 * 1000 * -1
  );

  return {
    ...token,
    access_token: response.data.access,
    expires_in: expirationTime,
  };
};

export const authConfig: AuthOptions = {
  providers: [
    CredentialsProvider({
      name: "Credentials",
      credentials: {
        email: {
          label: "Email",
          type: "text",
          placeholder: "jsmith@example.com",
        },
        password: { label: "Password", type: "password" },
      },
      async authorize(credentials, req): Promise<any> {
        if (!credentials?.email || !credentials?.password) return null;

        const { email, password } = credentials;
        const data = {
          email,
          password,
        };

        const res = await apiInstance.post<ITokens>("/auth/login/", data);
        console.log(res);
        if ([200, 201].includes(res.status)) {
          // const currentTime = new Date();
          // const expirationTime = new Date(currentTime.getTime() + 14 * 60000);
          // expirationTime.setTime(
          //   expirationTime.getTime() +
          //     expirationTime.getTimezoneOffset() * 60 * 1000 * -1
          // );

          const user = {
            refresh_token: res.data.refresh_token,
            access_token: res.data.access_token,
            expires_in: res.data.expires_in,
          };

          return user;
        }

        return null;
      },
    }),
  ],
  pages: {
    signIn: "/sign-in",
  },
  session: {
    strategy: "jwt",
  },
  callbacks: {
    async signIn({ account, user }) {
      return true;
    },
    async jwt({ token, user }) {
      if (user) return { ...token, ...user };

      const UTC = new Date();
      const currentTime = new Date(UTC.getTime());
      currentTime.setTime(
        currentTime.getTime() + currentTime.getTimezoneOffset() * 60 * 1000 * -1
      );

      const isValid =
        new Date(currentTime).getTime() <= new Date(token.expires_in).getTime();

      if (isValid) return token;

      return await refreshToken(token);
    },

    async session({ token, session }) {
      session.access_token = token.access_token;
      session.refresh_token = token.refresh_token;
      session.expires_in = token.expires_in;

      return session;
    },
  },
};
