import { useSession } from "next-auth/react";
import { Link, usePathname } from "@/shared/config/navigation";
import { useTranslations } from "next-intl";

interface INavAuthProps {
  responsible?: boolean;
  setOpenMenu: (open: boolean) => void;
}

const NavAuth: React.FC<INavAuthProps> = ({ responsible, setOpenMenu }) => {
  const t = useTranslations("navigation");
  const session = useSession();
  const auth = session.status === "authenticated";
  const pathname = usePathname();
  const isActiveProfile = pathname === "/profile";
  const isActiveSignIn = pathname === "/sign-in";

  const linkStyles = (isActive: boolean) =>
    `w-fit px-5 py-3 border-3 rounded-lg font-semibold transition-colors duration-300 ${
      responsible
        ? isActive
          ? "bg-[#3695d8] text-white"
          : "bg-white text-[#3695d8] border-[#3695d8]"
        : "bg-[#3695d8] text-white border-[#3695d8]"
    }`;

  return (
    <>
      {auth ? (
        <Link
          onClick={() => setOpenMenu(false)}
          href="/profile/personal"
          className={linkStyles(isActiveProfile)}
        >
          {t("profile")}
        </Link>
      ) : (
        <Link
          onClick={() => setOpenMenu(false)}
          href="/sign-in"
          className={linkStyles(isActiveSignIn)}
        >
          {t("login")}
        </Link>
      )}
    </>
  );
};

export default NavAuth;
