"use client";

import { useEffect, useState } from "react";
import { useNewsStore } from "./newsStore";
import NewsCard from "@/entities/NewsCard";
import Pagination from "@/features/Pagination/Pagination";

interface INewsListProps {
  searchParams: {
    ["страница-новостей"]: string;
  };
}

const NewsList: React.FC<INewsListProps> = ({
  searchParams,
}: INewsListProps) => {
  const [activePage, setActivePage] = useState<number>(
    +searchParams["страница-новостей"] || 1
  );
  const { data: news, getNews, isLoading, error } = useNewsStore();

  useEffect(() => {
    getNews(activePage);
  }, [activePage]);
  return (
    <div className="flex flex-col gap-4">
      <ul className="flex gap-[30px] flex-wrap mb-[96px]">
        {news.results.map((news) => (
          <li key={news.id}>
            <NewsCard
              id={news.id}
              title={news.title}
              content={news.content}
              image={news.image}
              date={news.created_at}
            />
          </li>
        ))}
      </ul>
      <hr></hr>
      <div className="mx-auto mb-[96px]">
        <Pagination
          activePage={activePage}
          setActivePage={setActivePage}
          prev={news.previous}
          next={news.next}
          count={news.count as number}
          current_count={news.results.length}
          limit={9}
        />
      </div>
    </div>
  );
};

export default NewsList;
