"use client";
import React, { useEffect, useState } from "react";
import { useTendersStore } from "./tendersStore";
import TenderCard from "@/entities/TenderCard";
import Pagination from "@/features/Pagination/Pagination";
import SearchForm from "@/features/SearchForm/SearchForm";

interface Props {
  searchParams: {
    ["страница-тендеров"]: string;
  };
}
const TendersList: React.FC<Props> = ({ searchParams }) => {
  const [activePage, setActivePage] = useState<number>(
    +searchParams["страница-тендеров"] || 1
  );
  const { data: tenders, getTenders, isLoading, error } = useTendersStore();

  useEffect(() => {
    getTenders(activePage);
  }, [activePage]);
  console.log(tenders);
  const handleSubmit = () => {};
  return (
    <div>
      <SearchForm
        placeholder="Введите ключевое слово"
        handleSubmit={handleSubmit}
      />

      <div className="flex flex-col gap-2 pb-[96px] items-center">
        {tenders?.results?.map((tender) => (
          <TenderCard
            key={tender.id}
            id={tender.id}
            id_of_card={tender.id_of_card}
            data_rk={tender.data_rk}
            name_of_organization={tender.name_of_organization}
            type_of_buy={tender.type_of_buy}
            name_of_buy={tender.name_of_buy}
            date_of_publication_datetime={tender.date_of_publication_datetime}
            date_of_offer_datetime={tender.date_of_offer_datetime}
            current_timestamp={tender.current_timestamp}
            plan_summ_decimal={tender.plan_summ_decimal}
            address_of_organization={tender.address_of_organization}
          />
        ))}
        <Pagination
          activePage={activePage}
          setActivePage={setActivePage}
          prev={tenders.previous}
          next={tenders.next}
          count={tenders.count as number}
          current_count={tenders.results.length}
          limit={10}
        />
      </div>
    </div>
  );
};

export default TendersList;
